CurrencyEditingController class
A NumberEditingTextController that formats input as a currency amount.
Currency-specific options like currencyName, currencySymbol, and decimalSeparator can be changed at any time.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
TextEditingValue> - TextEditingController
- CurrencyEditingController
- Implemented types
Constructors
Properties
- allowNegative ↔ bool
-
Whether negative number input is allowed.
getter/setter pairinherited
- currencyName ↔ String?
-
The 3-letter ISO 4217 currency code (e.g. USD, EUR, TRY).
getter/setter pair
- currencySymbol ↔ String?
-
The currency symbol (e.g. $, €, ₺).
getter/setter pair
- currencySymbolPosition → CurrencySymbolPosition
-
Whether the currency symbol is placed before or after the number
in the current locale.
no setter
- decimalSeparator ↔ String?
-
The symbol used to separate the decimal part.
getter/setter pair
- groupSeparator ↔ String?
-
The symbol used to group digits (e.g.
,in1,000).getter/setter pairinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- locale ↔ String?
-
The locale used for number formatting.
getter/setter pairinherited
- number ↔ num?
-
The underlying numeric value extracted from the formatted text.
getter/setter pairinherited
- resolvedCurrencySymbol → String
-
The resolved currency symbol used for formatting.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection ↔ TextSelection
-
The currently selected range within text.
getter/setter pairinherited
- showCurrencySymbol ↔ bool
-
Whether the currency symbol is shown in the formatted text.
getter/setter pair
- text ↔ String
-
The current string the user is editing.
getter/setter pairinherited
- value ↔ TextEditingValue
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
buildTextSpan(
{required BuildContext context, TextStyle? style, required bool withComposing}) → TextSpan -
Builds TextSpan from current editing value.
inherited
-
clear(
) → void -
Set the value to empty.
inherited
-
clearComposing(
) → void -
Set the composing region to an empty range.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited