locale property
The locale used for number formatting.
Setting this rebuilds the format and reformats the current value.
Implementation
@override
String? get locale => _locale;
The locale used for number formatting.
Setting this rebuilds the format and reformats the current value.
@override
String? get locale => _locale;