allowNegative property
Whether negative number input is allowed.
Setting this rebuilds the format and reformats the current value.
Implementation
@override
bool get allowNegative => _allowNegative;
Whether negative number input is allowed.
Setting this rebuilds the format and reformats the current value.
@override
bool get allowNegative => _allowNegative;