IntegerEditingController class

A NumberEditingTextController that formats input as an integer.

Inheritance
Implemented types

Constructors

IntegerEditingController({String? locale, num? value, String? groupSeparator, bool allowNegative = true})
Creates a controller for formatting input as an integer.

Properties

allowNegative bool
Whether negative number input is allowed.
getter/setter pairinherited
groupSeparator String?
The symbol used to group digits (e.g. , in 1,000).
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
locale String?
The locale used for number formatting.
getter/setter pairinherited
number num?
The underlying numeric value extracted from the formatted text.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection TextSelection
The currently selected range within text.
getter/setter pairinherited
text String
The current string the user is editing.
getter/setter pairinherited
value TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
buildTextSpan({required BuildContext context, TextStyle? style, required bool withComposing}) TextSpan
Builds TextSpan from current editing value.
inherited
clear() → void
Set the value to empty.
inherited
clearComposing() → void
Set the composing region to an empty range.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited